summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/hwp/mc_config
diff options
context:
space:
mode:
authorPRACHI GUPTA <pragupta@us.ibm.com>2015-03-09 11:44:15 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2015-05-19 19:16:30 -0500
commitba7b110d036d4027b6ec9474b5f737c5eef8fca3 (patch)
treeec5c1826d9b6f8224830dd7f7e7149b73084ba1f /src/usr/hwpf/hwp/mc_config
parentc5cae3414b24bcdcf182aba1f4af26ea289ca23a (diff)
downloadtalos-hostboot-ba7b110d036d4027b6ec9474b5f737c5eef8fca3.tar.gz
talos-hostboot-ba7b110d036d4027b6ec9474b5f737c5eef8fca3.zip
SW302259: INITPROC: FSP&Hostboot - hardware procedure changes from the
Change-Id: Idc00a24ad24505b820084690fdbca73d271544b1 CQ:SW302259 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/16935 Reviewed-by: PRACHI GUPTA <pragupta@us.ibm.com> Tested-by: PRACHI GUPTA <pragupta@us.ibm.com> Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/16951 Tested-by: Jenkins Server Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwpf/hwp/mc_config')
-rw-r--r--src/usr/hwpf/hwp/mc_config/mc_config.C2
-rw-r--r--src/usr/hwpf/hwp/mc_config/mss_eff_config/mss_eff_config.C16
2 files changed, 13 insertions, 5 deletions
diff --git a/src/usr/hwpf/hwp/mc_config/mc_config.C b/src/usr/hwpf/hwp/mc_config/mc_config.C
index a509047bb..e230b88b7 100644
--- a/src/usr/hwpf/hwp/mc_config/mc_config.C
+++ b/src/usr/hwpf/hwp/mc_config/mc_config.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2015 */
/* [+] Google Inc. */
/* [+] International Business Machines Corp. */
/* */
diff --git a/src/usr/hwpf/hwp/mc_config/mss_eff_config/mss_eff_config.C b/src/usr/hwpf/hwp/mc_config/mss_eff_config/mss_eff_config.C
index 044d00488..525ef5d9a 100644
--- a/src/usr/hwpf/hwp/mc_config/mss_eff_config/mss_eff_config.C
+++ b/src/usr/hwpf/hwp/mc_config/mss_eff_config/mss_eff_config.C
@@ -22,7 +22,7 @@
/* permissions and limitations under the License. */
/* */
/* IBM_PROLOG_END_TAG */
-// $Id: mss_eff_config.C,v 1.50 2014/12/03 19:55:07 jdsloat Exp $
+// $Id: mss_eff_config.C,v 1.51 2015/03/13 19:13:44 asaetow Exp $
// $Source: /afs/awd/projects/eclipz/KnowledgeBase/.cvsroot/eclipz/chips/
// centaur/working/procedures/ipl/fapi/mss_eff_config.C,v $
//------------------------------------------------------------------------------
@@ -45,7 +45,8 @@
//------------------------------------------------------------------------------
// Version:| Author: | Date: | Comment:
//---------|----------|---------|-----------------------------------------------
// 1.50 | asaetow |03-DEC-14| Removed string data types that are not supported.
// 1.49 | asaetow |01-DEC-14| Added RDIMM SPD/VPD support for ATTR_EFF_DIMM_RCD_CNTL_WORD_0_15 to take in SPD bits69:76 thru new VPD attribute ATTR_VPD_DIMM_RCD_CNTL_WORD_0_15.
// | | | Added ATTR_VPD_DIMM_RCD_IBT and ATTR_VPD_DIMM_RCD_OUTPUT_TIMING merge, per meeting with Ken and Dan P.
// | | | NOTE: DO NOT pickup w/o getMBvpdTermData.C v1.18 or newer from Dan.C and Corey.
@@ -371,7 +372,7 @@ struct mss_eff_config_atts
uint8_t eff_dimm_size[PORT_SIZE][DIMM_SIZE];
uint8_t eff_dimm_type;
uint8_t eff_custom_dimm;
- uint8_t eff_dram_al; // Always use AL = CL - 1.
+ uint8_t eff_dram_al; // Based on 2N/2T or 1N/1T enable
uint8_t eff_dram_asr;
uint8_t eff_dram_bl;
uint8_t eff_dram_banks;
@@ -1225,8 +1226,15 @@ fapi::ReturnCode mss_eff_config_setup_eff_atts(
fapi::ReturnCode rc;
const fapi::Target& TARGET_MBA = i_target_mba;
+ uint8_t mss_dram_2n_mode_enable;
+ rc = FAPI_ATTR_GET(ATTR_VPD_DRAM_2N_MODE_ENABLED, &i_target_mba, mss_dram_2n_mode_enable);
+ if(rc) return rc;
// set select atts members to non-zero
- p_o_atts->eff_dram_al = fapi::ENUM_ATTR_EFF_DRAM_AL_CL_MINUS_1; // Always use AL = CL - 1.
+ if ( mss_dram_2n_mode_enable == fapi::ENUM_ATTR_VPD_DRAM_2N_MODE_ENABLED_TRUE ) {
+ p_o_atts->eff_dram_al = fapi::ENUM_ATTR_EFF_DRAM_AL_CL_MINUS_2; // Always use AL = CL - 2 for 2N/2T mode
+ } else {
+ p_o_atts->eff_dram_al = fapi::ENUM_ATTR_EFF_DRAM_AL_CL_MINUS_1; // Always use AL = CL - 1 for 1N/1T mode
+ }
// Transfer powerdown request from system attr to DRAM attr
uint8_t mss_power_control_requested;
OpenPOWER on IntegriCloud
@@ -45,7 +45,8 @@
// Version:| Author: | Date: | Comment:
//---------|----------|---------|-----------------------------------------------
-// 1.50 | asaetow |03-DEC-14| Removed string data types that are not supported.
+// 1.51 | asaetow |13-MAR-15| Changed DRAM_AL to be CL-2 in 2N/2T mode and CL-1 in 1N/1T mode.
+// 1.50 | jdsloat |03-DEC-14| Removed string data types that are not supported.
// 1.49 | asaetow |01-DEC-14| Added RDIMM SPD/VPD support for ATTR_EFF_DIMM_RCD_CNTL_WORD_0_15 to take in SPD bits69:76 thru new VPD attribute ATTR_VPD_DIMM_RCD_CNTL_WORD_0_15.
// | | | Added ATTR_VPD_DIMM_RCD_IBT and ATTR_VPD_DIMM_RCD_OUTPUT_TIMING merge, per meeting with Ken and Dan P.